@@ -1,5 +1,5 @@
 import requests
-from .crypt import encrypt, decrypt
+from hesabe import crypt
 import json
 
 key = None
@@ -14,15 +14,13 @@ class Hesabe(object):
 
     def checkout(self):
         try:
-            encrypted = encrypt(self.data, key, iv)
+            encrypted = crypt.encrypt(self.data, key, iv)
         except:
             return{'error': 'key or iv is incorrect please check'}
         payload = encrypted
-        # print('encrypted data : ',encrypted)
         response = requests.request("POST", url, headers={'accessCode': accessCode}, data=payload)
-        # print('response encrypted data: ', json.loads(response.text))
-        if json.loads(response.text)['message'] == "Authentication failed.":
-            return {'error': "Authentication failed, please check access code"}
-        else:
-            decrypted = decrypt(response.text, key, iv)
+        try:
+            decrypted = crypt.decrypt(response.text, key, iv)
             return decrypted
+        except:
+            return {'error': "Authentication failed, please check access code"}
